## Plotting: PL


```{eval-rst}
.. module:: scanpy.external.pl
.. currentmodule:: scanpy.external
```

```{eval-rst}
.. autosummary::
   :toctree: ../generated/

   pl.phate
   pl.trimap
   pl.sam
   pl.wishbone_marker_trajectory
```
